<?php
/*
Plugin Name: Pages Children
Plugin URI: 
Description: Display Pages heirarchy a single level pages at a time. 
Author: Paul Menard
Version: 1.1
Author URI: http://www.codehooligans.com
*/

define('PAGES_CHILDREN_I18N_DOMAIN', 	'pages-children');

class PagesChildren {
	
	function PagesChildren() {

		add_action( 'init', 						array(&$this, 'init' ));
		add_action( 'admin_init', 					array(&$this, 'admin_init' ));
		add_action( 'admin_head', 					array(&$this, 'admin_head' ));
		add_action( 'query_string', 				array(&$this, 'query_string' ));
	}
	
	function init() {
		$plugin_dir = basename(dirname(__FILE__))."/lang";
		load_plugin_textdomain( PAGES_CHILDREN_I18N_DOMAIN, null, $plugin_dir );
		
	}
		
	function admin_init() {
		if ($this->check_page())
		{
			add_filter( 'page_row_actions', array(&$this, 'page_row_actions_filter'), 10, 2 );
		}
	}

	function admin_head() {
		if ($this->check_page())
		{
			?>
			<style type="text/css">
				table th.column-child-pages {
					width: 10%;
				}
				div#pages-nav-breadcrumb {
					margin-bottom: 10px;
				}
			</style>
			<?php
			// If we are showing a child section we provide a breadcrumb at the top 
			if (isset($_GET['post_parent']))
			{
				if (intval($_GET['post_parent']) > 0)
				{
					$parent_page = get_page(intval($_GET['post_parent']));
					if ($parent_page)
					{
						?>
						<script type="text/javascript">
							jQuery(document).ready( function($) {
								jQuery('div .tablenav').after('<div id="pages-nav-breadcrumb">&nbsp; <?php 
								echo _e('Back to Parent:', PAGES_CHILDREN_I18N_DOMAIN); ?> <?php
								echo $this->show_pages_parents($_GET['post_parent']); ?></div>');
								
								jQuery('table tr td.page-title a.row-title').each(function(){
									//var link_text_parts = jQuery(this).text().split('&#8212; ');	// Does not work!
									var link_text_parts = jQuery(this).text().split('— ');
									if (link_text_parts.length > 0)
									{
										var link_text_new = "";
										for (idx in link_text_parts)
										{
											if (link_text_parts[idx] != "")
											{
												if (link_text_new.length > 0)
													link_text_new = link_text_new+" ";
													link_text_new = link_text_new+link_text_parts[idx];
											}
										}
										if (link_text_new.length > 0)
											jQuery(this).text(link_text_new);
									}
								});
							});
						</script>			
						<?php
					}
				}
			}
			?>
			<script type="text/javascript">
				jQuery(document).ready( function($) {

					jQuery('table tr td.page-title strong').each(function(){
						var title_text_new = "";

						var title_strong = jQuery(this).html();
						var str_pos = title_strong.indexOf('| Parent Page:');
						if (str_pos > -1) // we have a hit
							title_text_new = title_strong.substr(0, str_pos-1);
						else
							title_text_new = title_strong;
							
						var parent_td = jQuery(this).parent();										
						var has_children = jQuery('div.row-actions span.pages-children', parent_td);
						if (has_children.length > 0)
						{
							var has_children_anchor = jQuery(has_children).html();
							title_text_new = title_text_new+" ("+has_children_anchor+" &raquo;)";
						}
						jQuery(this).html(title_text_new);
						jQuery('a.pages-children', this).text("<?php _e('sub-pages', PAGES_CHILDREN_I18N_DOMAIN); ?>");
						
					});
				});
			</script>			
			<?php
		}
	}
	
	
	function check_uri($url) {
		if (!$url) return;

		$_REQUEST_URI = explode('?', $_SERVER['REQUEST_URI']);
		$url_len 	= strlen($url);
		$url_offset = $url_len * -1;

		// If out test string ($url) is longer than the page URL. skip
		if (strlen($_REQUEST_URI[0]) < $url_len) return;

		if ($url == substr($_REQUEST_URI[0], $url_offset, $url_len))
				return true;		
	}	
	
	function check_page()
	{
		global $wp_version;

	    if ( version_compare( $wp_version, '2.9.999', '>' ) )
		{
			if (((isset($_GET['post_type'])) && ($_GET['post_type'] == 'page')) && ($this->check_uri('wp-admin/edit.php')))
			{
				if (isset($_GET['post_status']))
				{
					if ($_GET['post_status'] != "trash")
						return true;
				}
				else 
					return true;
			}
		}
		else
		{
			if ($this->check_uri('wp-admin/edit-pages.php'))
			{
				if (isset($_GET['post_status']))
				{
					if ($_GET['post_status'] != "trash")
						return true;
				}
				else 
					return true;
			}
		}		
	}

	function query_string($qs)
	{
		if ($this->check_page())
		{
			if (!isset($_REQUEST['s']))
			{
				if (isset($_GET['post_parent']))
				{
					$qs .= "&post_parent=". $_GET['post_parent'];
				}
				else
				{
					$qs .= "&post_parent=0";
				}
			}
		}
		return $qs;
	}

	function page_row_actions_filter($actions, $post )
	{
		global $wp_version;
		
		if (!array_key_exists('pages-children', $actions))
		{			
			$child_pages = get_pages( "parent=". $post->ID ."&child_of=". $post->ID );
			if ($child_pages)
			{
				if ($this->check_page())
				{
				    if ( version_compare( $wp_version, '2.9.999', '>' ) )
						$actions['pages-children'] = '<a class="pages-children" href="edit.php?post_type=page&post_parent='. 
							$post->ID .'">'. __('View Sub-Pages', PAGES_CHILDREN_I18N_DOMAIN). '</a>';
					else
						$actions['pages-children'] = '<a class="pages-children" href="edit-pages.php?post_parent='. 
							$post->ID .'">'. __('View Sub-Pages', PAGES_CHILDREN_I18N_DOMAIN) .'</a>';
				}
			}
		}
		return $actions;
	}
	
	// Given a page id will go up the tree to the top parent then display a breadcrumb listing
	function show_pages_parents($page_id='')
	{
		global $wp_version;
		
		if (!$page_id) return;
		
		$breadcrumb_str = '';
		$parent_page = get_page($page_id);

		$get_post_parent = 0;
		if (isset($_GET['post_parent']))
		{
			$get_post_parent = intval($_GET['post_parent']);
		}
		
		if ($parent_page->post_parent > 0)
		{
			$breadcrumb_str = $this->show_pages_parents($parent_page->post_parent);
		}
		else
		{
			if ($this->check_page())
			{
				if ( version_compare( $wp_version, '2.9.999', '>' ) )
					$breadcrumb_str .= '<a href="edit.php?post_type=page">'. __('Pages', PAGES_CHILDREN_I18N_DOMAIN) .'</a>';
			    else
					$breadcrumb_str .= '<a href="edit-pages.php">'. __('Pages', PAGES_CHILDREN_I18N_DOMAIN) .'</a>';
			}
		}
		if ($breadcrumb_str) $breadcrumb_str .= " &raquo; ";

		if ($get_post_parent == $parent_page->ID)
		{
			$breadcrumb_str .= get_the_title($parent_page->ID);
		}
		else
		{
			if ($this->check_page())
			{
				if ( version_compare( $wp_version, '2.9.999', '>' ) )
					$breadcrumb_str .= '<a href="edit.php?post_type=page&post_parent='. 
						$parent_page->ID .'">'. get_the_title($parent_page->ID) .'</a>';
				else
					$breadcrumb_str .= '<a href="edit-pages.php?post_parent='. 
						$parent_page->ID .'">'. get_the_title($parent_page->ID) .'</a>';
			}			
		}
		return 	$breadcrumb_str;
	}
	
	function activation_hook() {
		
	}

}
$pages_children = new PagesChildren();
?>